@@ -272,7 +272,8 @@ class CodeMagics(Magics):
         Usage:\\
           %load [options] source
 
-          where source can be a filename, URL, input history range or macro
+          where source can be a filename, URL, input history range, macro, or
+          element in the user namespace
 
         Options:
 
@@ -285,6 +286,8 @@ class CodeMagics(Magics):
 
           -y : Don't ask confirmation for loading source above 200 000 characters.
 
+          -n : Include the user's namespace when searching for source code.
+
         This magic command can either take a local filename, a URL, an history
         range (see %history) or a macro as argument, it will prompt for
         confirmation before loading source with more than 200 000 characters, unless
@@ -297,14 +300,18 @@ class CodeMagics(Magics):
         %load -r 5-10 myscript.py
         %load -r 10-20,30,40: foo.py
         %load -s MyClass,wonder_function myscript.py
+        %load -n MyClass
+        %load -n my_module.wonder_function
         """
-        opts,args = self.parse_options(arg_s,'ys:r:')
+        opts,args = self.parse_options(arg_s,'yns:r:')
 
         if not args:
             raise UsageError('Missing filename, URL, input history range, '
-                             'or macro.')
+                             'macro, or element in the user namespace.')
 
-        contents = self.shell.find_user_code(args)
+        search_ns = 'n' in opts
+
+        contents = self.shell.find_user_code(args, search_ns=search_ns)
 
         if 's' in opts:
             try:
@@ -346,7 +353,9 @@ class CodeMagics(Magics):
                 print('Operation cancelled.')
                 return
 
-        self.shell.set_next_input(contents)
+        contents = "# %load {}\n".format(arg_s) + contents
+
+        self.shell.set_next_input(contents, replace=True)
 
     @staticmethod
     def _find_edit_target(shell, args, opts, last_call):
