@@ -1,56 +1,23 @@
-"""Manage IPython.parallel clusters in the notebook.
+"""Manage IPython.parallel clusters in the notebook."""
 
-Authors:
-
-* Brian Granger
-"""
-
-#-----------------------------------------------------------------------------
-#  Copyright (C) 2008-2011  The IPython Development Team
-#
-#  Distributed under the terms of the BSD License.  The full license is in
-#  the file COPYING, distributed as part of this software.
-#-----------------------------------------------------------------------------
-
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
+# Copyright (c) IPython Development Team.
+# Distributed under the terms of the Modified BSD License.
 
 from tornado import web
-from zmq.eventloop import ioloop
 
 from IPython.config.configurable import LoggingConfigurable
-from IPython.utils.traitlets import Dict, Instance, CFloat
-from IPython.parallel.apps.ipclusterapp import IPClusterStart
+from IPython.utils.traitlets import Dict, Instance, Float
 from IPython.core.profileapp import list_profiles_in
 from IPython.core.profiledir import ProfileDir
 from IPython.utils import py3compat
 from IPython.utils.path import get_ipython_dir
 
 
-#-----------------------------------------------------------------------------
-# Classes
-#-----------------------------------------------------------------------------
-
-
-class DummyIPClusterStart(IPClusterStart):
-    """Dummy subclass to skip init steps that conflict with global app.
-    
-    Instantiating and initializing this class should result in fully configured
-    launchers, but no other side effects or state.
-    """
-
-    def init_signal(self):
-        pass
-    def reinit_logging(self):
-        pass
-
-
 class ClusterManager(LoggingConfigurable):
 
     profiles = Dict()
 
-    delay = CFloat(1., config=True,
+    delay = Float(1., config=True,
         help="delay (in s) between starting the controller and the engines")
 
     loop = Instance('zmq.eventloop.ioloop.IOLoop')
@@ -59,6 +26,20 @@ class ClusterManager(LoggingConfigurable):
         return IOLoop.instance()
 
     def build_launchers(self, profile_dir):
+        from IPython.parallel.apps.ipclusterapp import IPClusterStart
+        
+        class DummyIPClusterStart(IPClusterStart):
+            """Dummy subclass to skip init steps that conflict with global app.
+    
+            Instantiating and initializing this class should result in fully configured
+            launchers, but no other side effects or state.
+            """
+
+            def init_signal(self):
+                pass
+            def reinit_logging(self):
+                pass
+        
         starter = DummyIPClusterStart(log=self.log)
         starter.initialize(['--profile-dir', profile_dir])
         cl = starter.controller_launcher
@@ -73,16 +54,24 @@ class ClusterManager(LoggingConfigurable):
     def update_profiles(self):
         """List all profiles in the ipython_dir and cwd.
         """
+        
+        stale = set(self.profiles)
         for path in [get_ipython_dir(), py3compat.getcwd()]:
             for profile in list_profiles_in(path):
+                if profile in stale:
+                    stale.remove(profile)
                 pd = self.get_profile_dir(profile, path)
                 if profile not in self.profiles:
-                    self.log.debug("Adding cluster profile '%s'" % profile)
+                    self.log.debug("Adding cluster profile '%s'", profile)
                     self.profiles[profile] = {
                         'profile': profile,
                         'profile_dir': pd,
                         'status': 'stopped'
                     }
+        for profile in stale:
+            # remove profiles that no longer exist
+            self.log.debug("Profile '%s' no longer exists", profile)
+            self.profiles.pop(profile)
 
     def list_profiles(self):
         self.update_profiles()
@@ -131,11 +120,13 @@ class ClusterManager(LoggingConfigurable):
                 esl.stop()
             clean_data()
         cl.on_stop(controller_stopped)
-
-        dc = ioloop.DelayedCallback(lambda: cl.start(), 0, self.loop)
-        dc.start()
-        dc = ioloop.DelayedCallback(lambda: esl.start(n), 1000*self.delay, self.loop)
-        dc.start()
+        loop = self.loop
+        
+        def start():
+            """start the controller, then the engines after a delay"""
+            cl.start()
+            loop.add_timeout(self.loop.time() + self.delay, lambda : esl.start(n))
+        self.loop.add_callback(start)
 
         self.log.debug('Cluster started')
         data['controller_launcher'] = cl
