@@ -1,4 +1,4 @@
-"""ImageWidget class.  
+"""Image class.  
 
 Represents an image in the frontend using a widget.
 """
@@ -15,13 +15,21 @@ Represents an image in the frontend using a widget.
 #-----------------------------------------------------------------------------
 import base64
 
-from .widget import DOMWidget
+from .widget import DOMWidget, register
 from IPython.utils.traitlets import Unicode, CUnicode, Bytes
+from IPython.utils.warn import DeprecatedClass
 
 #-----------------------------------------------------------------------------
 # Classes
 #-----------------------------------------------------------------------------
-class ImageWidget(DOMWidget):
+@register('IPython.Image')
+class Image(DOMWidget):
+    """Displays an image as a widget.
+
+    The `value` of this widget accepts a byte string.  The byte string is the raw
+    image data that you want the browser to display.  You can explicitly define
+    the format of the byte string using the `format` trait (which defaults to
+    "png")."""
     _view_name = Unicode('ImageView', sync=True)
     
     # Define the custom state properties to sync with the front-end
@@ -33,3 +41,7 @@ class ImageWidget(DOMWidget):
     value = Bytes()
     def _value_changed(self, name, old, new):
         self._b64value = base64.b64encode(new)
+
+
+# Remove in IPython 4.0
+ImageWidget = DeprecatedClass(Image, 'ImageWidget')
