@@ -36,6 +36,8 @@ class RevealHelpPreprocessor(Preprocessor):
             #Make sure the cell has slideshow metadata.
             cell.metadata.slide_type = cell.get('metadata', {}).get('slideshow', {}).get('slide_type', '-')
 
+        for index, cell in enumerate(nb.cells):
+
             # Get the slide type. If type is start, subslide, or slide,
             # end the last subslide/slide.
             if cell.metadata.slide_type in ['slide']:
@@ -48,9 +50,15 @@ class RevealHelpPreprocessor(Preprocessor):
                 nb.cells[index].metadata.frag_number = index
                 i = 1
                 while i < len(nb.cells) - index:
-                    nb.cells[index + i].metadata.frag_helper = 'fragment_end'
-                    nb.cells[index + i].metadata.frag_number = index
-                    i += 1
+                    # We need to break the loop when a new slide or subslide is
+                    # found to avoid the propagation of the data-fragment-index
+                    # across multiple slides/subslides
+                    if nb.cells[index + i].metadata.slideshow.slide_type in ['slide', 'subslide']:
+                        break
+                    else:
+                        nb.cells[index + i].metadata.frag_helper = 'fragment_end'
+                        nb.cells[index + i].metadata.frag_number = index
+                        i += 1
             # Restart the slide_helper when the cell status is changed
             # to other types.
             if cell.metadata.slide_type in ['-', 'skip', 'notes', 'fragment']:
